@@ -1,8 +1,10 @@
-from .fields import MsgFields as _MsgFields, MsgErrs as _MsgErrs
+from .fields import (MsgFields as _MsgFields, MsgErrs as _MsgErrs,
+                     MsgValues as _MsgValues)
 from .taskresultset import TaskResultSet
 from .taskresult import TaskResult, TaskSeed
 
 MsgFields = _MsgFields()
+MsgValues = _MsgValues()
 MsgErrs = _MsgErrs()
 TaskResultSet = TaskResultSet
 TaskResult = TaskResult
