@@ -57,10 +57,19 @@ class MsgFields(ConstantDict):
     NET_DESC = "netdesc"
     NET_NAME = "netname"
     NET_UPDATE_DATE = "netupdatedate"
+    OS_GUESS_ACCURACY = "osaccuracy"
+    OS_FINGERPRINTS = "osfingerprints"
+    OS_GUESS = "osguess"
+    OS_NAME = "osname"
     PATH = "path"
+    PORTS = "ports"
+    PORT_STATUS = "portstatus"
+    PORT_PROTO = "portproto"
+    PORT_NUM = "portnum"
     PHYSICAL_ADDRESS = "phyaddr"
     SCREENSHOT = "screenshot"
     SPIDER = "spider"
+    STATUS = "status"
     URL = "url"
     WHOIS = "whois"
     WHOIS_RAW = "raw"
@@ -104,6 +113,9 @@ class MsgErrs(ConstantDict):
 
     LOOKUP_FAILED = "LOOKUP_FAILED::{0}"
 
+    NMAP_EXEC_ERROR = "NMAP_EXEC_ERROR::{0}"
+    NMAP_PARSE_ERROR = "NMAP_PARSE_ERROR::{0}"
+
     RESULT_FAIL = "TASK_RESULT_FAIL::{0}"
     RESULT_INVALID = "RESULT_INVALID::{0}"
 
