@@ -104,6 +104,25 @@ DomainSchema = build_schema({
     }
 })
 
+GeoipSchema = build_schema({
+    "properties": {
+        F.GEOIP: {
+            "type": "object",
+            "patternProperties": {
+                ipv4v6re: {
+                    "type": "object",
+                    "properties": {
+                        F.COUNTRY_CODE: {"type": ["string", "null"]},
+                        F.LAT: {"type": ["number", "null"]},
+                        F.LONG: {"type": ["number", "null"]},
+                    }
+                }
+            },
+            "additionalProperties": False,
+        },
+    }
+})
+
 HostnameSchema = build_schema({
     "properties": {
         F.HOSTNAME: {"type": "string"},
@@ -138,19 +157,37 @@ IpsetSchema = build_schema({
     }
 })
 
-GeoipSchema = build_schema({
+OsfingerprintsSchema = build_schema({
     "properties": {
-        F.GEOIP: {
+        F.OS_FINGERPRINTS: {
             "type": "object",
             "patternProperties": {
                 ipv4v6re: {
-                    "type": "object",
+                    "type": ["object", "null"],
                     "properties": {
-                        F.COUNTRY_CODE: {"type": ["string", "null"]},
-                        F.LAT: {"type": ["number", "null"]},
-                        F.LONG: {"type": ["number", "null"]},
-                    }
-                }
+                        F.PORTS: {
+                            "type": "array",
+                            "items": {
+                                "type": "object",
+                                "properties": {
+                                    F.PORT_NUM: {"type": ["number"]},
+                                    F.PORT_PROTO: {"type": ["string"]},
+                                    F.PORT_STATUS: {"type": ["string"]},
+                                },
+                            },
+                        },
+                        F.OS_GUESS: {
+                            "type": "object",
+                            "properties": {
+                                F.OS_NAME: {"type": ["string"]},
+                                F.OS_GUESS_ACCURACY: {"type": ["number"]},
+                            },
+                        },
+                        F.STATUS: {
+                            "type": "string",
+                        },
+                    },
+                },
             },
             "additionalProperties": False,
         },
