@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
 from .taskresult import TaskResult
-from .fields import MsgFields as MSGF
+from .fields import MsgFields as MSGF, MsgErrs as MERR
+from .exceptions import TaskResultFailException
 
 
 class TaskResultSet(dict):
@@ -72,15 +73,18 @@ class TaskResultSet(dict):
         """
         Add a TaskResult to this TaskResultSet.
         """
+        missed_field_err = ("TaskResult must specify a {0}. Did you remember "
+                            "to finish() the task?")
+
         if not task_result.output_name:
-            raise ValueError("TaskResult must specify a task")
+            raise ValueError(missed_field_err.format("output_name"))
         if not task_result.task_name:
-            raise ValueError("TaskResult must specify a task")
-        if not task_result.output_name:
-            raise ValueError("TaskResult must specify a task")
+            raise ValueError(missed_field_err.format("task_name"))
+        if not task_result.task_version:
+            raise ValueError(missed_field_err.format("task_version"))
         if not task_result.tmoid:
-            raise ValueError("TaskResult must specify a target monitoring "
-                             "object id")
+            raise ValueError(missed_field_err.format(
+                "task monitoring object id"))
 
         self.setdefault(task_result.output_name, {
             MSGF.TASKRESULTS: {},
@@ -142,7 +146,8 @@ class TaskResultSet(dict):
     def get_output_tmoid(self, output_name, tmoid, schema=None):
         """
         Get a single TaskResult based on a task name and target monitoring
-        ID.
+        ID. Raises exceptions if output_name or tmoid not found.
+        Use when you want to get the result back, even if it's failed.
         """
         try:
             tmoid = str(int(tmoid))
@@ -161,4 +166,40 @@ class TaskResultSet(dict):
             self[output_name][MSGF.TASKRESULTS][tmoid],
             schema=schema
         )
+
         return tr
+
+    def get_output_tmoid_raise_fail(self, output_name, tmoid, schema=None):
+        """
+        Returns a TaskResult and error string tuple given output_name and
+        tmoid.
+        Returns None for TaskResult if there was any problem with the
+        TaskResult.
+        Use when you want a hard raise when a task result failed.
+        """
+        try:
+            tr = self.get_output_tmoid(output_name, tmoid, schema=schema)
+            if not tr.success:
+                raise TaskResultFailException(
+                    MERR.RESULT_FAIL.format(tr.err))
+            return tr
+        except Exception:
+            raise
+
+    def get_output_tmoid_or_none(self, output_name, tmoid, schema=None):
+        """
+        Returns a TaskResult and error string tuple given output_name and
+        tmoid.
+        Returns None for TaskResult if there was any problem with the
+        TaskResult.
+        Use when you want a soft failure when a task failed.
+        """
+        tr = None
+        err = None
+
+        try:
+            tr = self.get_output_tmoid_raise_fail(
+                output_name, tmoid, schema=schema)
+        except Exception as e:
+            err = e
+        return ((tr, err))
