@@ -184,6 +184,21 @@ class TestTaskResult(unittest.TestCase):
 
         self.assertEqual(tr.task_version, "3.4.5")
 
+    def test_agent_name_none(self):
+        tr = TaskResult(self.output_name, 100, self.task_name, "3.4.5")
+        tr.add("a", "result")
+        tr.finish()
+
+        self.assertEqual(tr.agent_name, None)
+
+    def test_agent_name(self):
+        tr = TaskResult(self.output_name, 100, self.task_name, "3.4.5",
+                        agent_name="agent1")
+        tr.add("a", "result")
+        tr.finish()
+
+        self.assertEqual(tr.agent_name, "agent1")
+
     def test_obj_json_import(self):
         base_time = datetime(2016, 01, 01, 0, 0, 0)
 
@@ -205,6 +220,30 @@ class TestTaskResult(unittest.TestCase):
         self.assertEqual(tr2.time_start, base_time.replace(tzinfo=utc))
         self.assertEqual(tr2.time_end, base_time.replace(tzinfo=utc))
 
+    def test_obj_json_import_with_agent(self):
+        base_time = datetime(2016, 01, 01, 0, 0, 0)
+
+        with freeze_time(base_time):
+            tr = TaskResult(self.output_name, 100, self.task_name, "1.1.1",
+                            agent_name="agent1")
+            tr.add("a", "My whois data")
+            tr.finish()
+
+        tr_json = json.dumps(tr)
+        logging.debug(tr_json)
+        tr2 = TaskResult.init_from_dict(self.output_name,
+                                        100, json.loads(tr_json))
+        logging.debug(tr2)
+        self.assertEqual(tr2.get_data("a"), "My whois data")
+        self.assertTrue(tr2.success)
+        self.assertEqual(tr2.err, None)
+        self.assertEqual(tr2.agent_name, "agent1")
+        self.assertEqual(tr2.task_name, self.task_name)
+        self.assertEqual(tr2.output_name, self.output_name)
+        self.assertEqual(tr2.task_version, "1.1.1")
+        self.assertEqual(tr2.time_start, base_time.replace(tzinfo=utc))
+        self.assertEqual(tr2.time_end, base_time.replace(tzinfo=utc))
+
     def test_schema_fail(self):
         tr = TaskResult(self.output_name, 100, self.task_name, "1.1.1")
         tr.add("nosuch", "My whois data")
